@@ -361,9 +361,9 @@ class Snapable(ZFSItem): # Abstract class for Pools and Datasets
         if isinstance(ds, Dataset): return ds
 
         if isinstance(self, Pool):
-            raise KeyError("Dataset '{}' not found in Pool '{}'.".format(name, self.name))
+            raise KeyError(f"Dataset '{name}' not found in Pool '{self.name}'.")
         else:
-            raise KeyError("Dataset '{}' not found in Dataset '{}'.".format(name, self.path))
+            raise KeyError(f"Dataset '{name}' not found in Dataset '{self.path}'.")
         
 
     # returns list(of str) or if with_depth == True then list(of tuple(of depth, Dataset))
@@ -380,8 +380,8 @@ class Snapable(ZFSItem): # Abstract class for Pools and Datasets
     # WARNING - Using this function to filter if snapshot contains a folder
     def get_snapshots(self, flt=True, index=False):
         if flt is True: flt = lambda _:True
-        assert inspect.isfunction(flt), "flt must either be True or a Function. Got: {}".format(type(flt))
-        assert isinstance(index, bool), "index must be a boolean. Got: {}".format(type(index))
+        assert inspect.isfunction(flt), f"flt must either be True or a Function. Got: {type(flt)}"
+        assert isinstance(index, bool), f"index must be a boolean. Got: {type(index)}"
         _ds_path = self.path
         res = []
         for idx, c in enumerate(self.children):
@@ -423,7 +423,7 @@ class Snapable(ZFSItem): # Abstract class for Pools and Datasets
             else:
                 if not k in find_opts: return default
                 v = find_opts[k]
-            assert isinstance(v, types), 'Invalid type for param {}. Expecting {} but got: {}'.format(k, types, type(v))
+            assert isinstance(v, types), f'Invalid type for param {k}. Expecting {types} but got: {type(v)}'
 
             if to_datetime and not isinstance(v, datetime):
                 return datetime(v.year, v.month, v.day)
@@ -476,7 +476,7 @@ class Snapable(ZFSItem): # Abstract class for Pools and Datasets
             if not tdelta is None:
                 raise AssertionError("tdelta cannot be specified when both dt_from and dt_to are specified")
             if dt_from >= dt_to:
-                raise AssertionError("dt_from ({}) must be < dt_to ({})".format(dt_from, dt_to))
+                raise AssertionError(f"dt_from ({dt_from}) must be < dt_to ({dt_to})")
             (dt_f, dt_t) = (dt_from, dt_to)
             f=__fil_dt
 
@@ -558,7 +558,7 @@ class Dataset(Snapable):
             if v is None: return None
             if isinstance(v, str): return [v]
             if isinstance(v, list): return v
-            raise AssertionError("{} can only be a str or list. Got: {}".format(k, type(v)))
+            raise AssertionError(f"{k} can only be a str or list. Got: {type(v)}")
 
 
         file_type = __tv('file_type', file_type)
@@ -591,8 +591,14 @@ class Dataset(Snapable):
 
         rows = list(map(lambda s: __row(s), stdout.splitlines()))
         diffs = []
-        for row in rows:
+        for i, row in enumerate(rows):
+            # if i == 429:
+            #     print("HERE")
             d = Diff(row, snap_left, snap_right)
+            if d.path_full.find('(on_delete_queue)') > 0:
+                # It looks to be an artefact of ZFS that does not actually exist in FS
+                # https://github.com/openzfs/zfs/blob/master/lib/libzfs/libzfs_diff.c
+                continue
             if not file_type is None and not d.file_type in file_type: continue
             if not chg_type is None and not d.chg_type in chg_type: continue
 
@@ -614,6 +620,7 @@ class Dataset(Snapable):
                         bIgn = True
                         break
                 if bIgn: continue
+
             diffs.append(d)
 
         return diffs
@@ -641,12 +648,12 @@ class Dataset(Snapable):
     # path must be an actual path on the system being analyzed
     def get_rel_path(self, path):
         self.assertHaveMounts()
-        assert isinstance(path, str), "argument passed is not a string. Got: {}".format(type(path))
+        assert isinstance(path, str), f"argument passed is not a string. Got: {type(path)}"
         p_real = os.path.abspath( expand_user(path) )
         p_real = os.path.realpath(p_real)
         mp = self.mountpoint
         if not p_real.find(mp) == 0:
-            raise KeyError('path given is not in current dataset mountpoint {}. Path: {}'.format(mp, path))
+            raise KeyError(f'path given is not in current dataset mountpoint {mp}. Path: {path}')
         return p_real.replace(mp, '')
 
 
@@ -690,7 +697,7 @@ class Snapshot(ZFSItem):
         assert isinstance(self.parent, Dataset), \
             "This function is only available for Snapshots of Datasets not Pools"
         self.parent.assertHaveMounts()
-        return "{}/.zfs/snapshot/{}".format(self.parent.mountpoint, self.name)
+        return f"{self.parent.mountpoint}/.zfs/snapshot/{self.name}"
     snap_path = property(_get_snap_path)
 
     
@@ -706,7 +713,7 @@ class Snapshot(ZFSItem):
             "This function is only available for Snapshots of Datasets not Pools"
         self.parent.assertHaveMounts()
         assert self.parent.mounted, \
-            "Parent Dataset {} is not mounted. Please verify datsset.mounted before calling this function".format(self.parent)
+            f"Parent Dataset {self.parent} is not mounted. Please verify datsset.mounted before calling this function"
 
         if path is None or not isinstance(path, str) or path.strip() == '':
             assert 0, "path must be a non-blank string"
@@ -715,7 +722,7 @@ class Snapshot(ZFSItem):
         snap_path_base = self.snap_path
         ds_mp = self.dataset.mountpoint
         if path_neweal.find(ds_mp) == -1:
-            raise KeyError("Path given is not within the dataset's mountpoint of {}. Path passed: {}".format(ds_mp, path))
+            raise KeyError(f"Path given is not within the dataset's mountpoint of {ds_mp}. Path passed: {path}")
         snap_path = "{}{}".format(snap_path_base, path_neweal.replace(ds_mp, ''))
         if os.path.exists(snap_path):
             return (True, snap_path)
@@ -762,17 +769,17 @@ class Diff():
             self.no_from_snap=True
             snap_left = None
         elif not isinstance(snap_left, Snapshot):
-            raise AssertionError("snap_left must be either a Snapshot or str('na-first'). Got: {}".format(type(snap_left)))
+            raise AssertionError(f"snap_left must be either a Snapshot or str('na-first'). Got: {type(snap_left)}")
 
         if isinstance(snap_right, str) and snap_right == '(present)':
             self.to_present=True
             snap_right = None
 
         elif not isinstance(snap_right, Snapshot):
-            raise AssertionError("snap_left must be either a Snapshot. Got: {}".format(type(snap_right)))
+            raise AssertionError(f"snap_left must be either a Snapshot. Got: {type(snap_right)}")
 
-        if not self.no_from_snap and not self.to_present and snap_left.creation >= snap_right.creation:
-            raise AssertionError("diff from creation ({}) is > or = to diff_to creation ({})".format(snap_left.creation, snap_right.creation))
+        if not self.no_from_snap and not self.to_present and snap_left.creation > snap_right.creation:
+            raise AssertionError(f"diff from creation ({snap_left.creation}) is > to diff_to creation ({snap_right.creation})")
 
         self.snap_left = snap_left
         self.snap_right = snap_right
@@ -783,7 +790,7 @@ class Diff():
         elif len(row) == 5:
             (inode_ts, chg_type, file_type, path, path_new) = row
         else:
-            raise Exception("Unexpected len: {}. Row = {}".format(len(row), row))
+            raise Exception(f"Unexpected len: {len(row)}. Row = {row}")
 
         chg_time = datetime.fromtimestamp(int(inode_ts[:inode_ts.find('.')]))
         self.chg_ts = inode_ts
@@ -834,13 +841,13 @@ class Diff():
     @staticmethod
     def get_file_type(s):
         assert (isinstance(s, str) and not s == ''), "argument must be a non-empty string"
-        assert s in Diff.FILE_TYPES, "ZFS Diff File type is invalid: '{}'".format(s)
+        assert s in Diff.FILE_TYPES, f"ZFS Diff File type is invalid: '{s}'"
         return Diff.FILE_TYPES[s]
 
     @staticmethod
     def get_change_type(s):
         assert (isinstance(s, str) and not s == ''), "argument must be a non-empty string"
-        assert s in Diff.CHANGE_TYPES, "ZFS Diff Change type is invalid: '{}'".format(s)
+        assert s in Diff.CHANGE_TYPES, f"ZFS Diff Change type is invalid: '{s}'"
         return Diff.CHANGE_TYPES[s]
 
     def __str__(self):
@@ -859,57 +866,57 @@ class Diff():
 # buildTimedelta()
 # Builds timedelta from string:
 # . tdelta is a timedelta -or- str(nC) where: n is an integer > 0 and C is one of:
-#   . y=year, m=month, w=week, d=day, H=hour, M=minute, s=second
+#   . Y=year, M=month, W=week, D=day, h=hour, m=minute, s=second
 # Note: month and year are imprecise and assume 30.4 and 365 days
-def buildTimedelta(tdelta):
+def buildTimedelta(tdelta) -> timedelta:
     if isinstance(tdelta, timedelta): return tdelta
     
     if not isinstance(tdelta, str):
-        raise AssertionError('tdelta must be a string')
+        raise KeyError('tdelta must be a string')
     elif len(tdelta) < 2:
-        raise AssertionError('len(tdelta) must be >= 2')
+        raise KeyError('len(tdelta) must be >= 2')
     n = tdelta[:-1]
     try:
         n = int(n)
-        if n < 1: raise AssertionError('tdelta must be > 0')
+        if n < 1: raise KeyError('tdelta must be > 0')
     except ValueError as ex:
-        raise AssertionError('Value passed for tdelta does not contain a number: {}'.format(tdelta))
+        raise KeyError(f'Value passed for tdelta does not contain a number: {tdelta}')
     
     c = tdelta[-1:]
-    if c == 'H':
+    if c == 'h':
         return timedelta(hours=n)
-    elif c == 'M':
-        return timedelta(minutes=n)
-    elif c == 'S':
-        return timedelta(seconds=n)
-    elif c == 'd':
-        return timedelta(days=n)
     elif c == 'm':
-        return timedelta(days=n*(365/12))
-    elif c == 'w':
+        return timedelta(minutes=n)
+    elif c == 's':
+        return timedelta(seconds=n)
+    elif c == 'D':
+        return timedelta(days=n)
+    elif c == 'W':
         return timedelta(weeks=n)
-    elif c == 'y':
+    elif c == 'M':
+        return timedelta(days=n*(365/12))
+    elif c == 'Y':
         return timedelta(days=n*365)
     else:
-        raise AssertionError('Unexpected datetime identifier, expecting one of y,m,w,d,H,M,S.')
+        raise KeyError('Unexpected datetime identifier, expecting one of Y,M,W,D,h,m,s')
 
 
 # calcDateRange()
 # Calculates a date range based on tdelta string passed
 # tdelta is a timedelta -or- str(nC) where: n is an integer > 0 and C is one of:
-# . y=year, m=month, w=week, d=day, H=hour, M=minute, s=second
+#  . Y=year, M=month, W=week, D=day, h=hour, m=minute, s=second
 # If dt_from is defined, return tuple: (dt_from, dt_from+tdelta)
 # If dt_to is defined, return tuple: (dt_from-tdelta, dt_to)
-def calcDateRange(tdelta, dt_from=None, dt_to=None):
-    if tdelta is None: raise AssertionError('tdelta is required')
+def calcDateRange(tdelta, dt_from:datetime=None, dt_to:datetime=None) -> tuple:
+    if tdelta is None: raise KeyError('tdelta is required')
     if dt_from and dt_to:
-        raise AssertionError('Only one of dt_from or dt_to must be defined')
+        raise KeyError('Only one of dt_from or dt_to must be defined')
     elif (not dt_from and not dt_to):
-        raise AssertionError('Please specify one of dt_from or dt_to')
+        raise KeyError('Please specify one of dt_from or dt_to')
     elif dt_from and not isinstance(dt_from, datetime):
-        raise AssertionError('dt_from must be  a datetime')
+        raise KeyError('dt_from must be  a datetime')
     elif dt_to and not isinstance(dt_to, datetime):
-        raise AssertionError('dt_to must be  a datetime')
+        raise KeyError('dt_to must be  a datetime')
 
     td = buildTimedelta(tdelta)
     
@@ -920,7 +927,7 @@ def calcDateRange(tdelta, dt_from=None, dt_to=None):
 
 
 def splitPath(s):
-    assert isinstance(s, str), "String not passed. Got: {}".format(type(s))
+    assert isinstance(s, str), f"String not passed. Got: {type(s)}"
     s = s.strip()
     assert not s == '', "Empty string passed"
     f = os.path.basename(s)
